// python wrapper for vtkIossReader
//
#define VTK_WRAPPING_CXX
#define VTK_STREAMS_FWD_ONLY
#include "vtkPythonArgs.h"
#include "vtkPythonOverload.h"
#include <cstddef>
#include <sstream>
#include "vtkVariant.h"
#include "vtkIndent.h"
#include "vtkIossReader.h"

#if defined(PYTHON_PACKAGE)
#define PYTHON_PACKAGE_SCOPE PYTHON_PACKAGE "."
#else
#define PYTHON_PACKAGE_SCOPE
#endif

extern "C" { VTK_ABI_EXPORT void PyVTKAddFile_vtkIossReader(PyObject *dict); }
extern "C" { PyObject *PyvtkIossReader_ClassNew(); }

#ifndef DECLARED_PyvtkReaderAlgorithm_ClassNew
extern "C" { PyObject *PyvtkReaderAlgorithm_ClassNew(); }
#define DECLARED_PyvtkReaderAlgorithm_ClassNew
#endif

static const char *PyvtkIossReader_Doc =
  "vtkIossReader - Reader for Ioss (Sierra IO System)\n\n"
  "Superclass: vtkReaderAlgorithm\n\n"
  "vtkIossReader is reader that uses the Ioss (Sierra IO System) library\n"
  "to read files. Currently, this reader support Exodus files.\n\n"
  "@section SpecifyingFiles Specifying Files\n\n"
  "One can select a single file to read using\n"
  "`vtkIossReader::SetFileName`. With Ioss, however, it is not uncommon\n"
  "to have a collection of files named using standard patterns\n"
  "(described in Section @ref IossNamingConventions). To support this\n"
  "use-case, the reader automatically scans for additionally files\n"
  "internally. To disable this behaviour, call\n"
  "`vtkIossReader::ScanForRelatedFilesOff`.\n\n"
  "Alternatively, the list of files to be read can be explicitly\n"
  "specified using `vtkIossReader::AddFileName`. Then too, if\n"
  "`ScanForRelatedFiles` is `true`, the reader will search for related\n"
  "files for each of the files specified.\n\n"
  "@section SelectingBlocksSets Selecting blocks and sets to read\n\n"
  "An Ioss file comprises of blocks and sets of various types. These are\n"
  "described by the enum `vtkIossReader::EntityType`.\n\n"
  "`vtkIossReader::GetEntitySelection` returns a `vtkDataArraySelection`\n"
  "instance for each of the entity types. This `vtkDataArraySelection`\n"
  "can be used to query the names for available blocks or sets and also\n"
  "select which ones to read.\n\n"
  "Typical usage is as follows:\n\n"
  "{.cpp}\n\n"
  "vtkNewreader; reader->SetFileName(...); reader->UpdateInformation();\n"
  "reader->GetElementBlockSelection()->EnableArray(\"Block0\");\n"
  "reader->GetEntitySelection(vtkIossReader::SIDESET)->DisableAllArrays()\n"
  ";\n\n"
  "By default, all blocks are enabled, while all sets are disabled.\n\n"
  "@section SelectingArrays Selecting arrays to read\n\n"
  "Similar to the block and set selection, arrays (or fields as Ioss\n"
  "refers to them) to read from each of the blocks or sets can be\n"
  "specified using the `vtkDataArraySelection` instance returned using\n"
  "`vtkIossReader::GetFieldSelection` (or one of its convenience\n"
  "variants).\n\n"
  "By default all arrays are enabled.\n\n"
  "@section IossNamingConventions Ioss Naming Conventions\n\n"
  "An Ioss complete dataset is referred to as a database. There can be\n"
  "multiple multiple timesteps in a single database. A single database\n"
  "may split among multiple files. When a database is split among\n"
  "multiple files, this is strictly spatial partitioning with each file\n"
  "storing part of the data for a specific partition. In this case, the\n"
  "files are named with suffix `.{NP}.{RANK}` where `{NP}` is the total\n"
  "number of partitions  and `{RANK}` is the partition number. For\n"
  "example, if database named `can.e` is split among four files\n"
  "representing 4 partitions, it will be named as follows:\n\n\n"
  "  can.e.4.0\n"
  "  can.e.4.1\n"
  "  can.e.4.2\n"
  "  can.e.4.3\n"
  " \n\n"
  "In this example, the database name is `can.e` while the `.4.[0-4]`\n"
  "suffix provides the partition information.\n\n"
  "Note, the database need not be split into multiple files. Thus, a\n"
  "writer may generate a single `can.e` file that has all the timesteps\n"
  "and paritions and still provide all information available when the\n"
  "database is split among multiple files.\n\n"
  "Multiple databases (with each stored in a single file or spatially\n"
  "split among files) can form a temporal sequence. This done by using\n"
  "another file naming convention. If the database name is followed by\n"
  "`-s.{RS}`, where `{RS}` is some number sequence), then the databases\n"
  "are treated as a temporal sequence with `{RS}` (called restart\n"
  "numbers) representing the temporal sequence order.\n\n"
  "The follow represents a temporal sequence:\n\n\n"
  "  mysimoutput.e-s.000\n"
  "  mysimoutput.e-s.001\n"
  "  mysimoutput.e-s.002\n"
  " \n\n"
  "You can use any number of digits for the restart number, but by\n"
  "convention the number used should be the same for all files. Also by\n"
  "convention, you can leave off the `-s.{RS}` suffix for the first\n"
  "file. The following sequence is internally the same as that above:\n\n\n"
  "  mysimoutput.e-s\n"
  "  mysimoutput.e-s.001\n"
  "  mysimoutput.e-s.002\n"
  " \n\n"
  "When a database in the temporal sequence is spatially split in\n"
  "multiple files, the corresponding filename is suffixed by the\n"
  "partition information. For example:\n\n\n"
  "  mysimoutput.e-s.2.0\n"
  "  mysimoutput.e-s.2.1\n"
  "  mysimoutput.e-s.001.2.0\n"
  "  mysimoutput.e-s.001.2.1\n"
  "  mysimoutput.e-s.002.2.0\n"
  "  mysimoutput.e-s.002.2.1\n"
  " \n\n"
  "In this case, the filenames take the form\n"
  "`{DBNAME}-s.{RS}.{NP}.{RANK}`, where `{DBNAME}` is the database name,\n"
  "`{RS}` is the restart number, `{NP}` is the number of spatial\n"
  "partitions and `{RANK}` is the spatial partition number.\n\n"
  "@section References References\n"
  "* [Sierra IO System](http://gsjaardema.github.io/seacas/)\n\n";

static PyTypeObject PyvtkIossReader_EntityType_Type = {
  PyVarObject_HEAD_INIT(&PyType_Type, 0)
  PYTHON_PACKAGE_SCOPE "vtkIOIoss.vtkIossReader.EntityType", // tp_name
  sizeof(PyIntObject), // tp_basicsize
  0, // tp_itemsize
  nullptr, // tp_dealloc
#if PY_VERSION_HEX >= 0x03080000
  0, // tp_vectorcall_offset
#else
  nullptr, // tp_print
#endif
  nullptr, // tp_getattr
  nullptr, // tp_setattr
  nullptr, // tp_compare
  nullptr, // tp_repr
  nullptr, // tp_as_number
  nullptr, // tp_as_sequence
  nullptr, // tp_as_mapping
  nullptr, // tp_hash
  nullptr, // tp_call
  nullptr, // tp_str
  nullptr, // tp_getattro
  nullptr, // tp_setattro
  nullptr, // tp_as_buffer
  Py_TPFLAGS_DEFAULT, // tp_flags
  nullptr, // tp_doc
  nullptr, // tp_traverse
  nullptr, // tp_clear
  nullptr, // tp_richcompare
  0, // tp_weaklistoffset
  nullptr, // tp_iter
  nullptr, // tp_iternext
  nullptr, // tp_methods
  nullptr, // tp_members
  nullptr, // tp_getset
  &PyInt_Type, // tp_base
  nullptr, // tp_dict
  nullptr, // tp_descr_get
  nullptr, // tp_descr_set
  0, // tp_dictoffset
  nullptr, // tp_init
  nullptr, // tp_alloc
  nullptr, // tp_new
  PyObject_Del, // tp_free
  nullptr, // tp_is_gc
  nullptr, // tp_bases
  nullptr, // tp_mro
  nullptr, // tp_cache
  nullptr, // tp_subclasses
  nullptr, // tp_weaklist
  VTK_WRAP_PYTHON_SUPPRESS_UNINITIALIZED
};

template<class T>
PyObject *PyvtkIossReader_EntityType_FromEnum(T val)
{
  return PyVTKEnum_New(&PyvtkIossReader_EntityType_Type, static_cast<int>(val));
}


static PyObject *
PyvtkIossReader_IsTypeOf(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "IsTypeOf");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkIossReader::IsTypeOf(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_IsA(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsA");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->IsA(temp0) :
      op->vtkIossReader::IsA(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_SafeDownCast(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "SafeDownCast");

  vtkObjectBase *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkObjectBase"))
  {
    vtkIossReader *tempr = vtkIossReader::SafeDownCast(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_NewInstance(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "NewInstance");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkIossReader *tempr = (ap.IsBound() ?
      op->NewInstance() :
      op->vtkIossReader::NewInstance());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
      if (result && PyVTKObject_Check(result))
      {
        PyVTKObject_GetObject(result)->UnRegister(nullptr);
        PyVTKObject_SetFlag(result, VTK_PYTHON_IGNORE_UNREGISTER, 1);
      }
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GetNumberOfGenerationsFromBaseType(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "GetNumberOfGenerationsFromBaseType");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    long long tempr = vtkIossReader::GetNumberOfGenerationsFromBaseType(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GetNumberOfGenerationsFromBase(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetNumberOfGenerationsFromBase");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    long long tempr = (ap.IsBound() ?
      op->GetNumberOfGenerationsFromBase(temp0) :
      op->vtkIossReader::GetNumberOfGenerationsFromBase(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_AddFileName(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "AddFileName");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->AddFileName(temp0);
    }
    else
    {
      op->vtkIossReader::AddFileName(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_ClearFileNames(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ClearFileNames");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->ClearFileNames();
    }
    else
    {
      op->vtkIossReader::ClearFileNames();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GetFileName(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetFileName");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    const char *tempr = (ap.IsBound() ?
      op->GetFileName(temp0) :
      op->vtkIossReader::GetFileName(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GetNumberOfFileNames(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetNumberOfFileNames");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetNumberOfFileNames() :
      op->vtkIossReader::GetNumberOfFileNames());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_SetFileName(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetFileName");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetFileName(temp0);
    }
    else
    {
      op->vtkIossReader::SetFileName(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_SetScanForRelatedFiles(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetScanForRelatedFiles");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  bool temp0 = false;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetScanForRelatedFiles(temp0);
    }
    else
    {
      op->vtkIossReader::SetScanForRelatedFiles(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GetScanForRelatedFiles(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetScanForRelatedFiles");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    bool tempr = (ap.IsBound() ?
      op->GetScanForRelatedFiles() :
      op->vtkIossReader::GetScanForRelatedFiles());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_ScanForRelatedFilesOn(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ScanForRelatedFilesOn");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->ScanForRelatedFilesOn();
    }
    else
    {
      op->vtkIossReader::ScanForRelatedFilesOn();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_ScanForRelatedFilesOff(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ScanForRelatedFilesOff");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->ScanForRelatedFilesOff();
    }
    else
    {
      op->vtkIossReader::ScanForRelatedFilesOff();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_SetGenerateFileId(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetGenerateFileId");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  bool temp0 = false;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetGenerateFileId(temp0);
    }
    else
    {
      op->vtkIossReader::SetGenerateFileId(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GetGenerateFileId(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetGenerateFileId");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    bool tempr = (ap.IsBound() ?
      op->GetGenerateFileId() :
      op->vtkIossReader::GetGenerateFileId());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GenerateFileIdOn(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GenerateFileIdOn");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->GenerateFileIdOn();
    }
    else
    {
      op->vtkIossReader::GenerateFileIdOn();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GenerateFileIdOff(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GenerateFileIdOff");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->GenerateFileIdOff();
    }
    else
    {
      op->vtkIossReader::GenerateFileIdOff();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_SetReadIds(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetReadIds");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  bool temp0 = false;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetReadIds(temp0);
    }
    else
    {
      op->vtkIossReader::SetReadIds(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GetReadIds(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetReadIds");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    bool tempr = (ap.IsBound() ?
      op->GetReadIds() :
      op->vtkIossReader::GetReadIds());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_ReadIdsOn(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ReadIdsOn");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->ReadIdsOn();
    }
    else
    {
      op->vtkIossReader::ReadIdsOn();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_ReadIdsOff(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ReadIdsOff");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->ReadIdsOff();
    }
    else
    {
      op->vtkIossReader::ReadIdsOff();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_SetRemoveUnusedPoints(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetRemoveUnusedPoints");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  bool temp0 = false;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetRemoveUnusedPoints(temp0);
    }
    else
    {
      op->vtkIossReader::SetRemoveUnusedPoints(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GetRemoveUnusedPoints(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetRemoveUnusedPoints");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    bool tempr = (ap.IsBound() ?
      op->GetRemoveUnusedPoints() :
      op->vtkIossReader::GetRemoveUnusedPoints());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_RemoveUnusedPointsOn(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "RemoveUnusedPointsOn");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->RemoveUnusedPointsOn();
    }
    else
    {
      op->vtkIossReader::RemoveUnusedPointsOn();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_RemoveUnusedPointsOff(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "RemoveUnusedPointsOff");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->RemoveUnusedPointsOff();
    }
    else
    {
      op->vtkIossReader::RemoveUnusedPointsOff();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_SetApplyDisplacements(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetApplyDisplacements");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  bool temp0 = false;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetApplyDisplacements(temp0);
    }
    else
    {
      op->vtkIossReader::SetApplyDisplacements(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GetApplyDisplacements(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetApplyDisplacements");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    bool tempr = (ap.IsBound() ?
      op->GetApplyDisplacements() :
      op->vtkIossReader::GetApplyDisplacements());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_ApplyDisplacementsOn(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ApplyDisplacementsOn");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->ApplyDisplacementsOn();
    }
    else
    {
      op->vtkIossReader::ApplyDisplacementsOn();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_ApplyDisplacementsOff(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ApplyDisplacementsOff");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->ApplyDisplacementsOff();
    }
    else
    {
      op->vtkIossReader::ApplyDisplacementsOff();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_SetReadGlobalFields(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetReadGlobalFields");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  bool temp0 = false;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetReadGlobalFields(temp0);
    }
    else
    {
      op->vtkIossReader::SetReadGlobalFields(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GetReadGlobalFields(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetReadGlobalFields");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    bool tempr = (ap.IsBound() ?
      op->GetReadGlobalFields() :
      op->vtkIossReader::GetReadGlobalFields());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_ReadGlobalFieldsOn(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ReadGlobalFieldsOn");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->ReadGlobalFieldsOn();
    }
    else
    {
      op->vtkIossReader::ReadGlobalFieldsOn();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_ReadGlobalFieldsOff(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ReadGlobalFieldsOff");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->ReadGlobalFieldsOff();
    }
    else
    {
      op->vtkIossReader::ReadGlobalFieldsOff();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_SetReadQAAndInformationRecords(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetReadQAAndInformationRecords");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  bool temp0 = false;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetReadQAAndInformationRecords(temp0);
    }
    else
    {
      op->vtkIossReader::SetReadQAAndInformationRecords(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GetReadQAAndInformationRecords(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetReadQAAndInformationRecords");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    bool tempr = (ap.IsBound() ?
      op->GetReadQAAndInformationRecords() :
      op->vtkIossReader::GetReadQAAndInformationRecords());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_ReadQAAndInformationRecordsOn(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ReadQAAndInformationRecordsOn");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->ReadQAAndInformationRecordsOn();
    }
    else
    {
      op->vtkIossReader::ReadQAAndInformationRecordsOn();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_ReadQAAndInformationRecordsOff(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ReadQAAndInformationRecordsOff");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->ReadQAAndInformationRecordsOff();
    }
    else
    {
      op->vtkIossReader::ReadQAAndInformationRecordsOff();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_SetController(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetController");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  vtkMultiProcessController *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkMultiProcessController"))
  {
    if (ap.IsBound())
    {
      op->SetController(temp0);
    }
    else
    {
      op->vtkIossReader::SetController(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GetController(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetController");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkMultiProcessController *tempr = (ap.IsBound() ?
      op->GetController() :
      op->vtkIossReader::GetController());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GetEntityTypeIsBlock(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "GetEntityTypeIsBlock");

  int temp0;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    bool tempr = vtkIossReader::GetEntityTypeIsBlock(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GetEntityTypeIsSet(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "GetEntityTypeIsSet");

  int temp0;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    bool tempr = vtkIossReader::GetEntityTypeIsSet(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GetDataAssemblyNodeNameForEntityType(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "GetDataAssemblyNodeNameForEntityType");

  int temp0;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    const char *tempr = vtkIossReader::GetDataAssemblyNodeNameForEntityType(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GetEntitySelection(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetEntitySelection");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    vtkDataArraySelection *tempr = (ap.IsBound() ?
      op->GetEntitySelection(temp0) :
      op->vtkIossReader::GetEntitySelection(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GetNodeBlockSelection(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetNodeBlockSelection");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkDataArraySelection *tempr = (ap.IsBound() ?
      op->GetNodeBlockSelection() :
      op->vtkIossReader::GetNodeBlockSelection());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GetEdgeBlockSelection(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetEdgeBlockSelection");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkDataArraySelection *tempr = (ap.IsBound() ?
      op->GetEdgeBlockSelection() :
      op->vtkIossReader::GetEdgeBlockSelection());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GetFaceBlockSelection(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetFaceBlockSelection");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkDataArraySelection *tempr = (ap.IsBound() ?
      op->GetFaceBlockSelection() :
      op->vtkIossReader::GetFaceBlockSelection());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GetElementBlockSelection(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetElementBlockSelection");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkDataArraySelection *tempr = (ap.IsBound() ?
      op->GetElementBlockSelection() :
      op->vtkIossReader::GetElementBlockSelection());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GetNodeSetSelection(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetNodeSetSelection");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkDataArraySelection *tempr = (ap.IsBound() ?
      op->GetNodeSetSelection() :
      op->vtkIossReader::GetNodeSetSelection());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GetEdgeSetSelection(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetEdgeSetSelection");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkDataArraySelection *tempr = (ap.IsBound() ?
      op->GetEdgeSetSelection() :
      op->vtkIossReader::GetEdgeSetSelection());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GetFaceSetSelection(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetFaceSetSelection");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkDataArraySelection *tempr = (ap.IsBound() ?
      op->GetFaceSetSelection() :
      op->vtkIossReader::GetFaceSetSelection());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GetElementSetSelection(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetElementSetSelection");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkDataArraySelection *tempr = (ap.IsBound() ?
      op->GetElementSetSelection() :
      op->vtkIossReader::GetElementSetSelection());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GetSideSetSelection(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetSideSetSelection");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkDataArraySelection *tempr = (ap.IsBound() ?
      op->GetSideSetSelection() :
      op->vtkIossReader::GetSideSetSelection());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GetFieldSelection(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetFieldSelection");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    vtkDataArraySelection *tempr = (ap.IsBound() ?
      op->GetFieldSelection(temp0) :
      op->vtkIossReader::GetFieldSelection(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GetNodeBlockFieldSelection(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetNodeBlockFieldSelection");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkDataArraySelection *tempr = (ap.IsBound() ?
      op->GetNodeBlockFieldSelection() :
      op->vtkIossReader::GetNodeBlockFieldSelection());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GetEdgeBlockFieldSelection(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetEdgeBlockFieldSelection");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkDataArraySelection *tempr = (ap.IsBound() ?
      op->GetEdgeBlockFieldSelection() :
      op->vtkIossReader::GetEdgeBlockFieldSelection());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GetFaceBlockFieldSelection(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetFaceBlockFieldSelection");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkDataArraySelection *tempr = (ap.IsBound() ?
      op->GetFaceBlockFieldSelection() :
      op->vtkIossReader::GetFaceBlockFieldSelection());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GetElementBlockFieldSelection(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetElementBlockFieldSelection");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkDataArraySelection *tempr = (ap.IsBound() ?
      op->GetElementBlockFieldSelection() :
      op->vtkIossReader::GetElementBlockFieldSelection());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GetNodeSetFieldSelection(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetNodeSetFieldSelection");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkDataArraySelection *tempr = (ap.IsBound() ?
      op->GetNodeSetFieldSelection() :
      op->vtkIossReader::GetNodeSetFieldSelection());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GetEdgeSetFieldSelection(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetEdgeSetFieldSelection");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkDataArraySelection *tempr = (ap.IsBound() ?
      op->GetEdgeSetFieldSelection() :
      op->vtkIossReader::GetEdgeSetFieldSelection());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GetFaceSetFieldSelection(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetFaceSetFieldSelection");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkDataArraySelection *tempr = (ap.IsBound() ?
      op->GetFaceSetFieldSelection() :
      op->vtkIossReader::GetFaceSetFieldSelection());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GetElementSetFieldSelection(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetElementSetFieldSelection");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkDataArraySelection *tempr = (ap.IsBound() ?
      op->GetElementSetFieldSelection() :
      op->vtkIossReader::GetElementSetFieldSelection());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GetSideSetFieldSelection(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetSideSetFieldSelection");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkDataArraySelection *tempr = (ap.IsBound() ?
      op->GetSideSetFieldSelection() :
      op->vtkIossReader::GetSideSetFieldSelection());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_RemoveAllEntitySelections(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "RemoveAllEntitySelections");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->RemoveAllEntitySelections();
    }
    else
    {
      op->vtkIossReader::RemoveAllEntitySelections();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_RemoveAllFieldSelections(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "RemoveAllFieldSelections");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->RemoveAllFieldSelections();
    }
    else
    {
      op->vtkIossReader::RemoveAllFieldSelections();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_RemoveAllSelections(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "RemoveAllSelections");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->RemoveAllSelections();
    }
    else
    {
      op->vtkIossReader::RemoveAllSelections();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_ReadMetaData(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ReadMetaData");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  vtkInformation *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkInformation"))
  {
    int tempr = (ap.IsBound() ?
      op->ReadMetaData(temp0) :
      op->vtkIossReader::ReadMetaData(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_ReadMesh(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ReadMesh");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  int temp0;
  int temp1;
  int temp2;
  int temp3;
  vtkDataObject *temp4 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(5) &&
      ap.GetValue(temp0) &&
      ap.GetValue(temp1) &&
      ap.GetValue(temp2) &&
      ap.GetValue(temp3) &&
      ap.GetVTKObject(temp4, "vtkDataObject"))
  {
    int tempr = (ap.IsBound() ?
      op->ReadMesh(temp0, temp1, temp2, temp3, temp4) :
      op->vtkIossReader::ReadMesh(temp0, temp1, temp2, temp3, temp4));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_ReadPoints(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ReadPoints");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  int temp0;
  int temp1;
  int temp2;
  int temp3;
  vtkDataObject *temp4 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(5) &&
      ap.GetValue(temp0) &&
      ap.GetValue(temp1) &&
      ap.GetValue(temp2) &&
      ap.GetValue(temp3) &&
      ap.GetVTKObject(temp4, "vtkDataObject"))
  {
    int tempr = (ap.IsBound() ?
      op->ReadPoints(temp0, temp1, temp2, temp3, temp4) :
      op->vtkIossReader::ReadPoints(temp0, temp1, temp2, temp3, temp4));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_ReadArrays(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ReadArrays");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  int temp0;
  int temp1;
  int temp2;
  int temp3;
  vtkDataObject *temp4 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(5) &&
      ap.GetValue(temp0) &&
      ap.GetValue(temp1) &&
      ap.GetValue(temp2) &&
      ap.GetValue(temp3) &&
      ap.GetVTKObject(temp4, "vtkDataObject"))
  {
    int tempr = (ap.IsBound() ?
      op->ReadArrays(temp0, temp1, temp2, temp3, temp4) :
      op->vtkIossReader::ReadArrays(temp0, temp1, temp2, temp3, temp4));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkIossReader_GetMTime(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetMTime");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkIossReader *op = static_cast<vtkIossReader *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    unsigned long tempr = (ap.IsBound() ?
      op->GetMTime() :
      op->vtkIossReader::GetMTime());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}

static PyMethodDef PyvtkIossReader_Methods[] = {
  {"IsTypeOf", PyvtkIossReader_IsTypeOf, METH_VARARGS,
   "V.IsTypeOf(string) -> int\nC++: static vtkTypeBool IsTypeOf(const char *type)\n\nReturn 1 if this class type is the same type of (or a subclass\nof) the named class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"IsA", PyvtkIossReader_IsA, METH_VARARGS,
   "V.IsA(string) -> int\nC++: vtkTypeBool IsA(const char *type) override;\n\nReturn 1 if this class is the same type of (or a subclass of) the\nnamed class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SafeDownCast", PyvtkIossReader_SafeDownCast, METH_VARARGS,
   "V.SafeDownCast(vtkObjectBase) -> vtkIossReader\nC++: static vtkIossReader *SafeDownCast(vtkObjectBase *o)\n\n"},
  {"NewInstance", PyvtkIossReader_NewInstance, METH_VARARGS,
   "V.NewInstance() -> vtkIossReader\nC++: vtkIossReader *NewInstance()\n\n"},
  {"GetNumberOfGenerationsFromBaseType", PyvtkIossReader_GetNumberOfGenerationsFromBaseType, METH_VARARGS,
   "V.GetNumberOfGenerationsFromBaseType(string) -> int\nC++: static vtkIdType GetNumberOfGenerationsFromBaseType(\n    const char *type)\n\nGiven a the name of a base class of this class type, return the\ndistance of inheritance between this class type and the named\nclass (how many generations of inheritance are there between this\nclass and the named class). If the named class is not in this\nclass's inheritance tree, return a negative value. Valid\nresponses will always be nonnegative. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"GetNumberOfGenerationsFromBase", PyvtkIossReader_GetNumberOfGenerationsFromBase, METH_VARARGS,
   "V.GetNumberOfGenerationsFromBase(string) -> int\nC++: vtkIdType GetNumberOfGenerationsFromBase(const char *type)\n    override;\n\nGiven the name of a base class of this class type, return the\ndistance of inheritance between this class type and the named\nclass (how many generations of inheritance are there between this\nclass and the named class). If the named class is not in this\nclass's inheritance tree, return a negative value. Valid\nresponses will always be nonnegative. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"AddFileName", PyvtkIossReader_AddFileName, METH_VARARGS,
   "V.AddFileName(string)\nC++: void AddFileName(const char *fname)\n\nAPI to set the filenames.\n"},
  {"ClearFileNames", PyvtkIossReader_ClearFileNames, METH_VARARGS,
   "V.ClearFileNames()\nC++: void ClearFileNames()\n\nAPI to set the filenames.\n"},
  {"GetFileName", PyvtkIossReader_GetFileName, METH_VARARGS,
   "V.GetFileName(int) -> string\nC++: const char *GetFileName(int index)\n\nAPI to set the filenames.\n"},
  {"GetNumberOfFileNames", PyvtkIossReader_GetNumberOfFileNames, METH_VARARGS,
   "V.GetNumberOfFileNames() -> int\nC++: int GetNumberOfFileNames()\n\nAPI to set the filenames.\n"},
  {"SetFileName", PyvtkIossReader_SetFileName, METH_VARARGS,
   "V.SetFileName(string)\nC++: void SetFileName(const char *fname)\n\nSet a single filename. Note, this will clear all existing\nfilenames.\n"},
  {"SetScanForRelatedFiles", PyvtkIossReader_SetScanForRelatedFiles, METH_VARARGS,
   "V.SetScanForRelatedFiles(bool)\nC++: void SetScanForRelatedFiles(bool value)\n\nWhen set to true, the reader can automatically locate and load\nadditional files that are part of the collection.\n"},
  {"GetScanForRelatedFiles", PyvtkIossReader_GetScanForRelatedFiles, METH_VARARGS,
   "V.GetScanForRelatedFiles() -> bool\nC++: virtual bool GetScanForRelatedFiles()\n\nWhen set to true, the reader can automatically locate and load\nadditional files that are part of the collection.\n"},
  {"ScanForRelatedFilesOn", PyvtkIossReader_ScanForRelatedFilesOn, METH_VARARGS,
   "V.ScanForRelatedFilesOn()\nC++: virtual void ScanForRelatedFilesOn()\n\nWhen set to true, the reader can automatically locate and load\nadditional files that are part of the collection.\n"},
  {"ScanForRelatedFilesOff", PyvtkIossReader_ScanForRelatedFilesOff, METH_VARARGS,
   "V.ScanForRelatedFilesOff()\nC++: virtual void ScanForRelatedFilesOff()\n\nWhen set to true, the reader can automatically locate and load\nadditional files that are part of the collection.\n"},
  {"SetGenerateFileId", PyvtkIossReader_SetGenerateFileId, METH_VARARGS,
   "V.SetGenerateFileId(bool)\nC++: virtual void SetGenerateFileId(bool _arg)\n\nWhen set to true, the reader will add a cell-data array for cells\nnamed 'file_id' which identifies the file number when reading\nspatially partitioned files.\n\nDefault is false.\n"},
  {"GetGenerateFileId", PyvtkIossReader_GetGenerateFileId, METH_VARARGS,
   "V.GetGenerateFileId() -> bool\nC++: virtual bool GetGenerateFileId()\n\nWhen set to true, the reader will add a cell-data array for cells\nnamed 'file_id' which identifies the file number when reading\nspatially partitioned files.\n\nDefault is false.\n"},
  {"GenerateFileIdOn", PyvtkIossReader_GenerateFileIdOn, METH_VARARGS,
   "V.GenerateFileIdOn()\nC++: virtual void GenerateFileIdOn()\n\nWhen set to true, the reader will add a cell-data array for cells\nnamed 'file_id' which identifies the file number when reading\nspatially partitioned files.\n\nDefault is false.\n"},
  {"GenerateFileIdOff", PyvtkIossReader_GenerateFileIdOff, METH_VARARGS,
   "V.GenerateFileIdOff()\nC++: virtual void GenerateFileIdOff()\n\nWhen set to true, the reader will add a cell-data array for cells\nnamed 'file_id' which identifies the file number when reading\nspatially partitioned files.\n\nDefault is false.\n"},
  {"SetReadIds", PyvtkIossReader_SetReadIds, METH_VARARGS,
   "V.SetReadIds(bool)\nC++: virtual void SetReadIds(bool _arg)\n\nWhen set to true (default), the reader will read ids associated\nwith elements.\n"},
  {"GetReadIds", PyvtkIossReader_GetReadIds, METH_VARARGS,
   "V.GetReadIds() -> bool\nC++: virtual bool GetReadIds()\n\nWhen set to true (default), the reader will read ids associated\nwith elements.\n"},
  {"ReadIdsOn", PyvtkIossReader_ReadIdsOn, METH_VARARGS,
   "V.ReadIdsOn()\nC++: virtual void ReadIdsOn()\n\nWhen set to true (default), the reader will read ids associated\nwith elements.\n"},
  {"ReadIdsOff", PyvtkIossReader_ReadIdsOff, METH_VARARGS,
   "V.ReadIdsOff()\nC++: virtual void ReadIdsOff()\n\nWhen set to true (default), the reader will read ids associated\nwith elements.\n"},
  {"SetRemoveUnusedPoints", PyvtkIossReader_SetRemoveUnusedPoints, METH_VARARGS,
   "V.SetRemoveUnusedPoints(bool)\nC++: void SetRemoveUnusedPoints(bool)\n\nNode related data, including point coordinates, point field data\netc. is typically shared between all blocks and sets. By default,\nthe reader will remove unused points for each block or set. To\navoid this, set this flag to false.\n\nDefault is true, unused points are removed.\n"},
  {"GetRemoveUnusedPoints", PyvtkIossReader_GetRemoveUnusedPoints, METH_VARARGS,
   "V.GetRemoveUnusedPoints() -> bool\nC++: virtual bool GetRemoveUnusedPoints()\n\nNode related data, including point coordinates, point field data\netc. is typically shared between all blocks and sets. By default,\nthe reader will remove unused points for each block or set. To\navoid this, set this flag to false.\n\nDefault is true, unused points are removed.\n"},
  {"RemoveUnusedPointsOn", PyvtkIossReader_RemoveUnusedPointsOn, METH_VARARGS,
   "V.RemoveUnusedPointsOn()\nC++: virtual void RemoveUnusedPointsOn()\n\nNode related data, including point coordinates, point field data\netc. is typically shared between all blocks and sets. By default,\nthe reader will remove unused points for each block or set. To\navoid this, set this flag to false.\n\nDefault is true, unused points are removed.\n"},
  {"RemoveUnusedPointsOff", PyvtkIossReader_RemoveUnusedPointsOff, METH_VARARGS,
   "V.RemoveUnusedPointsOff()\nC++: virtual void RemoveUnusedPointsOff()\n\nNode related data, including point coordinates, point field data\netc. is typically shared between all blocks and sets. By default,\nthe reader will remove unused points for each block or set. To\navoid this, set this flag to false.\n\nDefault is true, unused points are removed.\n"},
  {"SetApplyDisplacements", PyvtkIossReader_SetApplyDisplacements, METH_VARARGS,
   "V.SetApplyDisplacements(bool)\nC++: virtual void SetApplyDisplacements(bool _arg)\n\nWhen set to true (default), if an array named 'displacement' is\npresent in the node field arrays, it will be used to transform\nthe point coordinates.\n"},
  {"GetApplyDisplacements", PyvtkIossReader_GetApplyDisplacements, METH_VARARGS,
   "V.GetApplyDisplacements() -> bool\nC++: virtual bool GetApplyDisplacements()\n\nWhen set to true (default), if an array named 'displacement' is\npresent in the node field arrays, it will be used to transform\nthe point coordinates.\n"},
  {"ApplyDisplacementsOn", PyvtkIossReader_ApplyDisplacementsOn, METH_VARARGS,
   "V.ApplyDisplacementsOn()\nC++: virtual void ApplyDisplacementsOn()\n\nWhen set to true (default), if an array named 'displacement' is\npresent in the node field arrays, it will be used to transform\nthe point coordinates.\n"},
  {"ApplyDisplacementsOff", PyvtkIossReader_ApplyDisplacementsOff, METH_VARARGS,
   "V.ApplyDisplacementsOff()\nC++: virtual void ApplyDisplacementsOff()\n\nWhen set to true (default), if an array named 'displacement' is\npresent in the node field arrays, it will be used to transform\nthe point coordinates.\n"},
  {"SetReadGlobalFields", PyvtkIossReader_SetReadGlobalFields, METH_VARARGS,
   "V.SetReadGlobalFields(bool)\nC++: virtual void SetReadGlobalFields(bool _arg)\n\nWhen set to true (default), the reader will read global fields.\n"},
  {"GetReadGlobalFields", PyvtkIossReader_GetReadGlobalFields, METH_VARARGS,
   "V.GetReadGlobalFields() -> bool\nC++: virtual bool GetReadGlobalFields()\n\nWhen set to true (default), the reader will read global fields.\n"},
  {"ReadGlobalFieldsOn", PyvtkIossReader_ReadGlobalFieldsOn, METH_VARARGS,
   "V.ReadGlobalFieldsOn()\nC++: virtual void ReadGlobalFieldsOn()\n\nWhen set to true (default), the reader will read global fields.\n"},
  {"ReadGlobalFieldsOff", PyvtkIossReader_ReadGlobalFieldsOff, METH_VARARGS,
   "V.ReadGlobalFieldsOff()\nC++: virtual void ReadGlobalFieldsOff()\n\nWhen set to true (default), the reader will read global fields.\n"},
  {"SetReadQAAndInformationRecords", PyvtkIossReader_SetReadQAAndInformationRecords, METH_VARARGS,
   "V.SetReadQAAndInformationRecords(bool)\nC++: virtual void SetReadQAAndInformationRecords(bool _arg)\n\nWhen set to true (default), the reader will read quality\nassurance and information fields.\n"},
  {"GetReadQAAndInformationRecords", PyvtkIossReader_GetReadQAAndInformationRecords, METH_VARARGS,
   "V.GetReadQAAndInformationRecords() -> bool\nC++: virtual bool GetReadQAAndInformationRecords()\n\nWhen set to true (default), the reader will read quality\nassurance and information fields.\n"},
  {"ReadQAAndInformationRecordsOn", PyvtkIossReader_ReadQAAndInformationRecordsOn, METH_VARARGS,
   "V.ReadQAAndInformationRecordsOn()\nC++: virtual void ReadQAAndInformationRecordsOn()\n\nWhen set to true (default), the reader will read quality\nassurance and information fields.\n"},
  {"ReadQAAndInformationRecordsOff", PyvtkIossReader_ReadQAAndInformationRecordsOff, METH_VARARGS,
   "V.ReadQAAndInformationRecordsOff()\nC++: virtual void ReadQAAndInformationRecordsOff()\n\nWhen set to true (default), the reader will read quality\nassurance and information fields.\n"},
  {"SetController", PyvtkIossReader_SetController, METH_VARARGS,
   "V.SetController(vtkMultiProcessController)\nC++: void SetController(vtkMultiProcessController *controller)\n\nGet/Set the controller to use when working in parallel.\nInitialized to `vtkMultiProcessController::GetGlobalController`\nin the constructor.\n\nThe controller is used to using `ReadMetaData` stage to\ndistribute the work of gathering meta-data from multiple files,\nif any, across ranks and then exchanging that information between\nall ranks.\n\nThe actual reading of data is controlled by piece requests sent\nby the pipeline e.g. using `vtkAlgorithm::UpdatePiece`.\n"},
  {"GetController", PyvtkIossReader_GetController, METH_VARARGS,
   "V.GetController() -> vtkMultiProcessController\nC++: virtual vtkMultiProcessController *GetController()\n\nGet/Set the controller to use when working in parallel.\nInitialized to `vtkMultiProcessController::GetGlobalController`\nin the constructor.\n\nThe controller is used to using `ReadMetaData` stage to\ndistribute the work of gathering meta-data from multiple files,\nif any, across ranks and then exchanging that information between\nall ranks.\n\nThe actual reading of data is controlled by piece requests sent\nby the pipeline e.g. using `vtkAlgorithm::UpdatePiece`.\n"},
  {"GetEntityTypeIsBlock", PyvtkIossReader_GetEntityTypeIsBlock, METH_VARARGS,
   "V.GetEntityTypeIsBlock(int) -> bool\nC++: static bool GetEntityTypeIsBlock(int type)\n\n"},
  {"GetEntityTypeIsSet", PyvtkIossReader_GetEntityTypeIsSet, METH_VARARGS,
   "V.GetEntityTypeIsSet(int) -> bool\nC++: static bool GetEntityTypeIsSet(int type)\n\n"},
  {"GetDataAssemblyNodeNameForEntityType", PyvtkIossReader_GetDataAssemblyNodeNameForEntityType, METH_VARARGS,
   "V.GetDataAssemblyNodeNameForEntityType(int) -> string\nC++: static const char *GetDataAssemblyNodeNameForEntityType(\n    int type)\n\n"},
  {"GetEntitySelection", PyvtkIossReader_GetEntitySelection, METH_VARARGS,
   "V.GetEntitySelection(int) -> vtkDataArraySelection\nC++: vtkDataArraySelection *GetEntitySelection(int type)\n\n"},
  {"GetNodeBlockSelection", PyvtkIossReader_GetNodeBlockSelection, METH_VARARGS,
   "V.GetNodeBlockSelection() -> vtkDataArraySelection\nC++: vtkDataArraySelection *GetNodeBlockSelection()\n\n"},
  {"GetEdgeBlockSelection", PyvtkIossReader_GetEdgeBlockSelection, METH_VARARGS,
   "V.GetEdgeBlockSelection() -> vtkDataArraySelection\nC++: vtkDataArraySelection *GetEdgeBlockSelection()\n\n"},
  {"GetFaceBlockSelection", PyvtkIossReader_GetFaceBlockSelection, METH_VARARGS,
   "V.GetFaceBlockSelection() -> vtkDataArraySelection\nC++: vtkDataArraySelection *GetFaceBlockSelection()\n\n"},
  {"GetElementBlockSelection", PyvtkIossReader_GetElementBlockSelection, METH_VARARGS,
   "V.GetElementBlockSelection() -> vtkDataArraySelection\nC++: vtkDataArraySelection *GetElementBlockSelection()\n\n"},
  {"GetNodeSetSelection", PyvtkIossReader_GetNodeSetSelection, METH_VARARGS,
   "V.GetNodeSetSelection() -> vtkDataArraySelection\nC++: vtkDataArraySelection *GetNodeSetSelection()\n\n"},
  {"GetEdgeSetSelection", PyvtkIossReader_GetEdgeSetSelection, METH_VARARGS,
   "V.GetEdgeSetSelection() -> vtkDataArraySelection\nC++: vtkDataArraySelection *GetEdgeSetSelection()\n\n"},
  {"GetFaceSetSelection", PyvtkIossReader_GetFaceSetSelection, METH_VARARGS,
   "V.GetFaceSetSelection() -> vtkDataArraySelection\nC++: vtkDataArraySelection *GetFaceSetSelection()\n\n"},
  {"GetElementSetSelection", PyvtkIossReader_GetElementSetSelection, METH_VARARGS,
   "V.GetElementSetSelection() -> vtkDataArraySelection\nC++: vtkDataArraySelection *GetElementSetSelection()\n\n"},
  {"GetSideSetSelection", PyvtkIossReader_GetSideSetSelection, METH_VARARGS,
   "V.GetSideSetSelection() -> vtkDataArraySelection\nC++: vtkDataArraySelection *GetSideSetSelection()\n\n"},
  {"GetFieldSelection", PyvtkIossReader_GetFieldSelection, METH_VARARGS,
   "V.GetFieldSelection(int) -> vtkDataArraySelection\nC++: vtkDataArraySelection *GetFieldSelection(int type)\n\n"},
  {"GetNodeBlockFieldSelection", PyvtkIossReader_GetNodeBlockFieldSelection, METH_VARARGS,
   "V.GetNodeBlockFieldSelection() -> vtkDataArraySelection\nC++: vtkDataArraySelection *GetNodeBlockFieldSelection()\n\n"},
  {"GetEdgeBlockFieldSelection", PyvtkIossReader_GetEdgeBlockFieldSelection, METH_VARARGS,
   "V.GetEdgeBlockFieldSelection() -> vtkDataArraySelection\nC++: vtkDataArraySelection *GetEdgeBlockFieldSelection()\n\n"},
  {"GetFaceBlockFieldSelection", PyvtkIossReader_GetFaceBlockFieldSelection, METH_VARARGS,
   "V.GetFaceBlockFieldSelection() -> vtkDataArraySelection\nC++: vtkDataArraySelection *GetFaceBlockFieldSelection()\n\n"},
  {"GetElementBlockFieldSelection", PyvtkIossReader_GetElementBlockFieldSelection, METH_VARARGS,
   "V.GetElementBlockFieldSelection() -> vtkDataArraySelection\nC++: vtkDataArraySelection *GetElementBlockFieldSelection()\n\n"},
  {"GetNodeSetFieldSelection", PyvtkIossReader_GetNodeSetFieldSelection, METH_VARARGS,
   "V.GetNodeSetFieldSelection() -> vtkDataArraySelection\nC++: vtkDataArraySelection *GetNodeSetFieldSelection()\n\n"},
  {"GetEdgeSetFieldSelection", PyvtkIossReader_GetEdgeSetFieldSelection, METH_VARARGS,
   "V.GetEdgeSetFieldSelection() -> vtkDataArraySelection\nC++: vtkDataArraySelection *GetEdgeSetFieldSelection()\n\n"},
  {"GetFaceSetFieldSelection", PyvtkIossReader_GetFaceSetFieldSelection, METH_VARARGS,
   "V.GetFaceSetFieldSelection() -> vtkDataArraySelection\nC++: vtkDataArraySelection *GetFaceSetFieldSelection()\n\n"},
  {"GetElementSetFieldSelection", PyvtkIossReader_GetElementSetFieldSelection, METH_VARARGS,
   "V.GetElementSetFieldSelection() -> vtkDataArraySelection\nC++: vtkDataArraySelection *GetElementSetFieldSelection()\n\n"},
  {"GetSideSetFieldSelection", PyvtkIossReader_GetSideSetFieldSelection, METH_VARARGS,
   "V.GetSideSetFieldSelection() -> vtkDataArraySelection\nC++: vtkDataArraySelection *GetSideSetFieldSelection()\n\n"},
  {"RemoveAllEntitySelections", PyvtkIossReader_RemoveAllEntitySelections, METH_VARARGS,
   "V.RemoveAllEntitySelections()\nC++: void RemoveAllEntitySelections()\n\n"},
  {"RemoveAllFieldSelections", PyvtkIossReader_RemoveAllFieldSelections, METH_VARARGS,
   "V.RemoveAllFieldSelections()\nC++: void RemoveAllFieldSelections()\n\n"},
  {"RemoveAllSelections", PyvtkIossReader_RemoveAllSelections, METH_VARARGS,
   "V.RemoveAllSelections()\nC++: void RemoveAllSelections()\n\n"},
  {"ReadMetaData", PyvtkIossReader_ReadMetaData, METH_VARARGS,
   "V.ReadMetaData(vtkInformation) -> int\nC++: int ReadMetaData(vtkInformation *metadata) override;\n\nImplementation for vtkReaderAlgorithm API\n"},
  {"ReadMesh", PyvtkIossReader_ReadMesh, METH_VARARGS,
   "V.ReadMesh(int, int, int, int, vtkDataObject) -> int\nC++: int ReadMesh(int piece, int npieces, int nghosts,\n    int timestep, vtkDataObject *output) override;\n\nImplementation for vtkReaderAlgorithm API\n"},
  {"ReadPoints", PyvtkIossReader_ReadPoints, METH_VARARGS,
   "V.ReadPoints(int, int, int, int, vtkDataObject) -> int\nC++: int ReadPoints(int, int, int, int, vtkDataObject *) override;\n\nImplementation for vtkReaderAlgorithm API\n"},
  {"ReadArrays", PyvtkIossReader_ReadArrays, METH_VARARGS,
   "V.ReadArrays(int, int, int, int, vtkDataObject) -> int\nC++: int ReadArrays(int, int, int, int, vtkDataObject *) override;\n\nImplementation for vtkReaderAlgorithm API\n"},
  {"GetMTime", PyvtkIossReader_GetMTime, METH_VARARGS,
   "V.GetMTime() -> int\nC++: vtkMTimeType GetMTime() override;\n\nOverridden to take into account mtimes for vtkDataArraySelection\ninstances.\n"},
  {nullptr, nullptr, 0, nullptr}
};

static PyTypeObject PyvtkIossReader_Type = {
  PyVarObject_HEAD_INIT(&PyType_Type, 0)
  PYTHON_PACKAGE_SCOPE "vtkIOIoss.vtkIossReader", // tp_name
  sizeof(PyVTKObject), // tp_basicsize
  0, // tp_itemsize
  PyVTKObject_Delete, // tp_dealloc
#if PY_VERSION_HEX >= 0x03080000
  0, // tp_vectorcall_offset
#else
  nullptr, // tp_print
#endif
  nullptr, // tp_getattr
  nullptr, // tp_setattr
  nullptr, // tp_compare
  PyVTKObject_Repr, // tp_repr
  nullptr, // tp_as_number
  nullptr, // tp_as_sequence
  nullptr, // tp_as_mapping
  nullptr, // tp_hash
  nullptr, // tp_call
  PyVTKObject_String, // tp_str
  PyObject_GenericGetAttr, // tp_getattro
  PyObject_GenericSetAttr, // tp_setattro
  &PyVTKObject_AsBuffer, // tp_as_buffer
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_BASETYPE, // tp_flags
  PyvtkIossReader_Doc, // tp_doc
  PyVTKObject_Traverse, // tp_traverse
  nullptr, // tp_clear
  nullptr, // tp_richcompare
  offsetof(PyVTKObject, vtk_weakreflist), // tp_weaklistoffset
  nullptr, // tp_iter
  nullptr, // tp_iternext
  nullptr, // tp_methods
  nullptr, // tp_members
  PyVTKObject_GetSet, // tp_getset
  nullptr, // tp_base
  nullptr, // tp_dict
  nullptr, // tp_descr_get
  nullptr, // tp_descr_set
  offsetof(PyVTKObject, vtk_dict), // tp_dictoffset
  nullptr, // tp_init
  nullptr, // tp_alloc
  PyVTKObject_New, // tp_new
  PyObject_GC_Del, // tp_free
  nullptr, // tp_is_gc
  nullptr, // tp_bases
  nullptr, // tp_mro
  nullptr, // tp_cache
  nullptr, // tp_subclasses
  nullptr, // tp_weaklist
  VTK_WRAP_PYTHON_SUPPRESS_UNINITIALIZED
};

static vtkObjectBase *PyvtkIossReader_StaticNew()
{
  return vtkIossReader::New();
}

PyObject *PyvtkIossReader_ClassNew()
{
  PyTypeObject *pytype = PyVTKClass_Add(
    &PyvtkIossReader_Type, PyvtkIossReader_Methods,
    "vtkIossReader",
 &PyvtkIossReader_StaticNew);

  if ((pytype->tp_flags & Py_TPFLAGS_READY) != 0)
  {
    return (PyObject *)pytype;
  }

#if !defined(VTK_PY3K) && PY_VERSION_HEX >= 0x02060000
  pytype->tp_flags |= Py_TPFLAGS_HAVE_NEWBUFFER;
#endif

  pytype->tp_base = vtkPythonUtil::FindClassTypeObject("vtkReaderAlgorithm");

  PyObject *d = pytype->tp_dict;
  PyObject *o;

  PyType_Ready(&PyvtkIossReader_EntityType_Type);
  PyVTKEnum_Add(&PyvtkIossReader_EntityType_Type, "vtkIossReader.EntityType");

  o = (PyObject *)&PyvtkIossReader_EntityType_Type;
  if (PyDict_SetItemString(d, "EntityType", o) != 0)
  {
    Py_DECREF(o);
  }

  for (int c = 0; c < 16; c++)
  {
    typedef vtkIossReader::EntityType cxx_enum_type;

    static const struct { const char *name; cxx_enum_type value; }
      constants[16] = {
        { "NODEBLOCK", vtkIossReader::NODEBLOCK },
        { "EDGEBLOCK", vtkIossReader::EDGEBLOCK },
        { "FACEBLOCK", vtkIossReader::FACEBLOCK },
        { "ELEMENTBLOCK", vtkIossReader::ELEMENTBLOCK },
        { "NODESET", vtkIossReader::NODESET },
        { "EDGESET", vtkIossReader::EDGESET },
        { "FACESET", vtkIossReader::FACESET },
        { "ELEMENTSET", vtkIossReader::ELEMENTSET },
        { "SIDESET", vtkIossReader::SIDESET },
        { "NUMBER_OF_ENTITY_TYPES", vtkIossReader::NUMBER_OF_ENTITY_TYPES },
        { "BLOCK_START", vtkIossReader::BLOCK_START },
        { "BLOCK_END", vtkIossReader::BLOCK_END },
        { "SET_START", vtkIossReader::SET_START },
        { "SET_END", vtkIossReader::SET_END },
        { "ENTITY_START", vtkIossReader::ENTITY_START },
        { "ENTITY_END", vtkIossReader::ENTITY_END },
      };

    o = PyvtkIossReader_EntityType_FromEnum(constants[c].value);
    if (o)
    {
      PyDict_SetItemString(d, constants[c].name, o);
      Py_DECREF(o);
    }
  }

  PyType_Ready(pytype);
  return (PyObject *)pytype;
}

void PyVTKAddFile_vtkIossReader(
  PyObject *dict)
{
  PyObject *o;
  o = PyvtkIossReader_ClassNew();

  if (o && PyDict_SetItemString(dict, "vtkIossReader", o) != 0)
  {
    Py_DECREF(o);
  }

}

